import "./tasks/mendelian.wdl" as mendelian
import "./tasks/zipIndex.wdl" as zipIndex
import "./tasks/VCFrename.wdl" as VCFrename
import "./tasks/mergeSister.wdl" as mergeSister
import "./tasks/reformVCF.wdl" as reformVCF


workflow {{ project_name }} {
	File inputSamplesFile
	Array[Array[File]] inputSamples = read_tsv(inputSamplesFile)
	File ref_dir
	String fasta
	String cluster_config
	String disk_size

	scatter (quartet in inputSamples){
		call mendelian.mendelian as LCL5mendelian {
			input:
			child_vcf=quartet[0],
			LCL7_vcf=quartet[2],
			LCL8_vcf=quartet[3],
			LCL7_name=quartet[6],
			LCL8_name=quartet[7],
			child_name=quartet[4],
			ref_dir=ref_dir,
			fasta=fasta,
			cluster_config=cluster_config,
			disk_size=disk_size
		}
		call mendelian.mendelian as LCL6mendelian {
			input:
			child_vcf=quartet[1],
			LCL7_vcf=quartet[2],
			LCL8_vcf=quartet[3],
			LCL7_name=quartet[6],
			LCL8_name=quartet[7],
			child_name=quartet[5],
			ref_dir=ref_dir,
			fasta=fasta,
			cluster_config=cluster_config,
			disk_size=disk_size
		}
		call zipIndex.zipIndex as LCL5zipIndex {
			input:
			vcf=LCL5mendelian.trio_vcf,
			cluster_config=cluster_config,
			disk_size=disk_size
		}
		call zipIndex.zipIndex as LCL6zipIndex {
			input:
			vcf=LCL6mendelian.trio_vcf,
			cluster_config=cluster_config,
			disk_size=disk_size
		}		
		call VCFrename.VCFrename as LCL5VCFrename {
			input:
			trio_vcf_gz=LCL5zipIndex.vcf_gz,
			trio_vcf_idx=LCL5zipIndex.vcf_idx,
			mother_name=quartet[7],
			father_name=quartet[6],
			child_name=quartet[4],
			family_name=quartet[8],
			child="LCL5",
			cluster_config=cluster_config,
			disk_size=disk_size
		}
		call VCFrename.VCFrename as LCL6VCFrename {
			input:
			trio_vcf_gz=LCL6zipIndex.vcf_gz,
			trio_vcf_idx=LCL6zipIndex.vcf_idx,
			mother_name=quartet[7],
			father_name=quartet[6],
			child_name=quartet[5],
			family_name=quartet[8],
			child="LCL6",
			cluster_config=cluster_config,
			disk_size=disk_size
		}
		call mergeSister.mergeSister as mergeSister {
			input:
			LCL5_trio_vcf_gz=LCL5VCFrename.rename_trio_vcf_gz,
			LCL5_trio_vcf_idx=LCL5VCFrename.rename_trio_vcf_idx,
			LCL6_trio_vcf_gz=LCL6VCFrename.rename_trio_vcf_gz,
			LCL6_trio_vcf_idx=LCL6VCFrename.rename_trio_vcf_idx,
			family_name=quartet[8],
			cluster_config=cluster_config,
			disk_size=disk_size
		}
		call reformVCF.reformVCF as reformVCF {
			input:
			family_mendelian_info=mergeSister.family_mendelian_info,
			family_name=quartet[8],
			cluster_config=cluster_config,
			disk_size=disk_size			
		}
	}
}